@@ -2,16 +2,16 @@
 # SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import os
+import pathlib
 import tempfile
-from typing import Iterable, Iterator, List, NamedTuple, Optional, Tuple
+from typing import Iterable, Iterator, List, NamedTuple, Optional, Tuple, Union
 
 import mypy.api
 import pytest
 from _pytest._code.code import ReprEntry, ReprFileLocation
 from _pytest.config import Config
-from py._path.local import LocalPath
 
-from .message import Message
+from .message import Message, Severity
 from .output_processing import OutputMismatch, diff_message_sequences
 from .parser import MypyTestItem, parse_file
 
@@ -36,6 +36,8 @@ class MypyAssertionError(AssertionError):
 
 
 class PytestMypyTestItem(pytest.Item):
+    parent: "PytestMypyFile"
+
     def __init__(
         self,
         name: str,
@@ -43,10 +45,11 @@ class PytestMypyTestItem(pytest.Item):
         *,
         mypy_item: MypyTestItem,
         config: Optional[Config] = None,
+        **kwargs,
     ) -> None:
         if config is None:
             config = parent.config
-        super().__init__(name, parent=parent, config=config)
+        super().__init__(name, parent=parent, config=config, **kwargs)
         self.add_marker("mypy")
         self.mypy_item = mypy_item
         for mark in self.mypy_item.marks:
@@ -71,7 +74,7 @@ class PytestMypyTestItem(pytest.Item):
         if errors:
             raise MypyAssertionError(item=self, errors=errors)
 
-    def reportinfo(self) -> Tuple[str, Optional[int], str]:
+    def reportinfo(self) -> Tuple[Union["os.PathLike[str]", str], Optional[int], str]:
         return self.parent.fspath, self.mypy_item.lineno, self.name
 
     def repr_failure(self, excinfo, style=None):
@@ -103,27 +106,42 @@ class PytestMypyTestItem(pytest.Item):
 
 class PytestMypyFile(pytest.File):
     def __init__(
-        self, fspath: LocalPath, parent=None, config=None, session=None, nodeid=None,
+        self,
+        *,
+        parent=None,
+        config=None,
+        session=None,
+        nodeid=None,
+        **kwargs,
     ) -> None:
         if config is None:
             config = getattr(parent, "config", None)
-        super().__init__(fspath, parent, config, session, nodeid)
+        super().__init__(
+            parent=parent,
+            config=config,
+            session=session,
+            nodeid=nodeid,
+            **kwargs,
+        )
         self.add_marker("mypy")
-        self.mypy_file = parse_file(self.fspath, config=config)
+        if PYTEST_VERSION_INFO >= (7,):
+            self.mypy_file = parse_file(self.path, config=config)
+        else:
+            self.mypy_file = parse_file(self.fspath, config=config)
         self._mypy_result: Optional[MypyResult] = None
 
     @classmethod
-    def from_parent(cls, parent, fspath):
+    def from_parent(cls, parent, **kwargs):
         if PYTEST_VERSION_INFO < (5, 4):
             config = getattr(parent, "config", None)
-            return cls(parent=parent, config=config, fspath=fspath)
+            return cls(parent=parent, config=config, **kwargs)
         else:
-            return super().from_parent(parent=parent, fspath=fspath)
+            return super().from_parent(parent=parent, **kwargs)
 
     def collect(self) -> Iterator[PytestMypyTestItem]:
         for item in self.mypy_file.items:
             yield PytestMypyTestItem.from_parent(
-                parent=self, name="[mypy]" + item.name, mypy_item=item,
+                parent=self, name="[mypy]" + item.name, mypy_item=item
             )
 
     def run_mypy(self, item: MypyTestItem) -> Tuple[int, List[Message]]:
@@ -137,9 +155,9 @@ class PytestMypyFile(pytest.File):
             ),
         )
 
-    def _run_mypy(self, filename: str) -> MypyResult:
+    def _run_mypy(self, filename: Union[pathlib.Path, os.PathLike, str]) -> MypyResult:
+        filename = pathlib.Path(filename)
         with tempfile.TemporaryDirectory(prefix="pytest-mypy-testing-") as tmp_dir_name:
-
             mypy_cache_dir = os.path.join(tmp_dir_name, "mypy_cache")
             os.makedirs(mypy_cache_dir)
 
@@ -150,6 +168,7 @@ class PytestMypyFile(pytest.File):
                 "--no-color-output",
                 "--no-error-summary",
                 "--no-pretty",
+                "--soft-error-limit=-1",
                 "--no-silence-site-packages",
                 "--no-warn-unused-configs",
                 "--show-column-numbers",
@@ -160,10 +179,16 @@ class PytestMypyFile(pytest.File):
             out, err, returncode = mypy.api.run(mypy_args)
 
         lines = (out + err).splitlines()
+
         file_messages = [
             msg
             for msg in map(Message.from_output, lines)
-            if msg.filename == self.mypy_file.filename
+            if (msg.filename == self.mypy_file.filename)
+            and not (
+                msg.severity is Severity.NOTE
+                and msg.message
+                == "See https://mypy.readthedocs.io/en/stable/running_mypy.html#missing-imports"
+            )
         ]
 
         non_item_messages = []
@@ -185,15 +210,26 @@ class PytestMypyFile(pytest.File):
         )
 
 
-def pytest_collect_file(path: LocalPath, parent):
-    if path.ext == ".mypy-testing" or _is_pytest_test_file(path, parent):
-        file = PytestMypyFile.from_parent(parent=parent, fspath=path)
-        if file.mypy_file.items:
-            return file
-    return None
+if PYTEST_VERSION_INFO < (7,):
+
+    def pytest_collect_file(path, parent):
+        if path.ext == ".mypy-testing" or _is_pytest_test_file(path, parent):
+            file = PytestMypyFile.from_parent(parent=parent, fspath=path)
+            if file.mypy_file.items:
+                return file
+        return None
+
+else:
+
+    def pytest_collect_file(file_path, path, parent):  # type: ignore
+        if path.ext == ".mypy-testing" or _is_pytest_test_file(path, parent):
+            file = PytestMypyFile.from_parent(parent=parent, path=file_path)
+            if file.mypy_file.items:
+                return file
+        return None
 
 
-def _is_pytest_test_file(path: LocalPath, parent):
+def _is_pytest_test_file(path, parent):
     """Return `True` if *path* is considered to be a pytest test file."""
     # Based on _pytest/python.py::pytest_collect_file
     fn_patterns = parent.config.getini("python_files") + ["__init__.py"]
@@ -222,4 +258,4 @@ def _add_reveal_type_to_builtins():
     import builtins
 
     if not hasattr(builtins, "reveal_type"):
-        setattr(builtins, "reveal_type", lambda x: x)
+        setattr(builtins, "reveal_type", lambda x: x)  # noqa: B010
